@@ -1,4 +1,7 @@
 """OpenAPI core contrib falcon responses module"""
+
+from itertools import tee
+
 from falcon.response import Response
 from werkzeug.datastructures import Headers
 
@@ -10,24 +13,29 @@ class FalconOpenAPIResponse:
         self.response = response
 
     @property
-    def data(self) -> str:
+    def data(self) -> bytes:
         if self.response.text is None:
-            return ""
+            if self.response.stream is None:
+                return b""
+            resp_iter1, resp_iter2 = tee(self.response.stream)
+            self.response.stream = resp_iter1
+            content = b"".join(resp_iter2)
+            return content
         assert isinstance(self.response.text, str)
-        return self.response.text
+        return self.response.text.encode("utf-8")
 
     @property
     def status_code(self) -> int:
         return int(self.response.status[:3])
 
     @property
-    def mimetype(self) -> str:
-        mimetype = ""
+    def content_type(self) -> str:
+        content_type = ""
         if self.response.content_type:
-            mimetype = self.response.content_type.partition(";")[0]
+            content_type = self.response.content_type
         else:
-            mimetype = self.response.options.default_media_type
-        return mimetype
+            content_type = self.response.options.default_media_type
+        return content_type
 
     @property
     def headers(self) -> Headers:
