@@ -1,4 +1,5 @@
 """OpenAPI core protocols module"""
+
 from typing import Any
 from typing import Mapping
 from typing import Optional
@@ -13,16 +14,13 @@ class BaseRequest(Protocol):
     parameters: RequestParameters
 
     @property
-    def method(self) -> str:
-        ...
+    def method(self) -> str: ...
 
     @property
-    def body(self) -> Optional[str]:
-        ...
+    def body(self) -> Optional[bytes]: ...
 
     @property
-    def mimetype(self) -> str:
-        ...
+    def content_type(self) -> str: ...
 
 
 @runtime_checkable
@@ -48,20 +46,16 @@ class Request(BaseRequest, Protocol):
             to write resolved path parameters.
         body
             The request body, as string.
-        mimetype
-            Like content type, but without parameters (eg, without charset,
-            type etc.) and always lowercase.
-            For example if the content type is "text/HTML; charset=utf-8"
-            the mimetype would be "text/html".
+        content_type
+            The content type with parameters (eg, charset, boundary etc.)
+            and always lowercase.
     """
 
     @property
-    def host_url(self) -> str:
-        ...
+    def host_url(self) -> str: ...
 
     @property
-    def path(self) -> str:
-        ...
+    def path(self) -> str: ...
 
 
 @runtime_checkable
@@ -78,16 +72,13 @@ class WebhookRequest(BaseRequest, Protocol):
             to write resolved path parameters.
         body
             The request body, as string.
-        mimetype
-            Like content type, but without parameters (eg, without charset,
-            type etc.) and always lowercase.
-            For example if the content type is "text/HTML; charset=utf-8"
-            the mimetype would be "text/html".
+        content_type
+            The content type with parameters (eg, charset, boundary etc.)
+            and always lowercase.
     """
 
     @property
-    def name(self) -> str:
-        ...
+    def name(self) -> str: ...
 
 
 @runtime_checkable
@@ -104,8 +95,7 @@ class SupportsPathPattern(Protocol):
     """
 
     @property
-    def path_pattern(self) -> str:
-        ...
+    def path_pattern(self) -> str: ...
 
 
 @runtime_checkable
@@ -119,22 +109,18 @@ class Response(Protocol):
             The status code as integer.
         headers
             Response headers as Headers.
-        mimetype
-            Lowercase content type without charset.
+        content_type
+            The content type with parameters and always lowercase.
     """
 
     @property
-    def data(self) -> str:
-        ...
+    def data(self) -> Optional[bytes]: ...
 
     @property
-    def status_code(self) -> int:
-        ...
+    def status_code(self) -> int: ...
 
     @property
-    def mimetype(self) -> str:
-        ...
+    def content_type(self) -> str: ...
 
     @property
-    def headers(self) -> Mapping[str, Any]:
-        ...
+    def headers(self) -> Mapping[str, Any]: ...
