@@ -1,20 +1,22 @@
 """OpenAPI core templating paths finders module"""
+
 from typing import Iterator
 from typing import List
 from typing import Optional
 from urllib.parse import urljoin
 from urllib.parse import urlparse
 
+from jsonschema_path import SchemaPath
 from more_itertools import peekable
 
 from openapi_core.schema.servers import is_absolute
-from openapi_core.spec import Spec
 from openapi_core.templating.datatypes import TemplateResult
 from openapi_core.templating.paths.datatypes import Path
 from openapi_core.templating.paths.datatypes import PathOperation
 from openapi_core.templating.paths.datatypes import PathOperationServer
 from openapi_core.templating.paths.exceptions import OperationNotFound
 from openapi_core.templating.paths.exceptions import PathNotFound
+from openapi_core.templating.paths.exceptions import PathsNotFound
 from openapi_core.templating.paths.exceptions import ServerNotFound
 from openapi_core.templating.paths.util import template_path_len
 from openapi_core.templating.util import parse
@@ -22,7 +24,7 @@ from openapi_core.templating.util import search
 
 
 class BasePathFinder:
-    def __init__(self, spec: Spec, base_url: Optional[str] = None):
+    def __init__(self, spec: SchemaPath, base_url: Optional[str] = None):
         self.spec = spec
         self.base_url = base_url
 
@@ -68,13 +70,15 @@ class BasePathFinder:
 
 
 class APICallPathFinder(BasePathFinder):
-    def __init__(self, spec: Spec, base_url: Optional[str] = None):
+    def __init__(self, spec: SchemaPath, base_url: Optional[str] = None):
         self.spec = spec
         self.base_url = base_url
 
     def _get_paths_iter(self, name: str) -> Iterator[Path]:
-        template_paths: List[Path] = []
         paths = self.spec / "paths"
+        if not paths.exists():
+            raise PathsNotFound(paths.as_uri())
+        template_paths: List[Path] = []
         for path_pattern, path in list(paths.items()):
             # simple path.
             # Return right away since it is always the most concrete
@@ -98,8 +102,10 @@ class APICallPathFinder(BasePathFinder):
             servers = (
                 path.get("servers", None)
                 or operation.get("servers", None)
-                or self.spec.get("servers", [{"url": "/"}])
+                or self.spec.get("servers", None)
             )
+            if not servers:
+                servers = [SchemaPath.from_dict({"url": "/"})]
             for server in servers:
                 server_url_pattern = name.rsplit(path_result.resolved, 1)[0]
                 server_url = server["url"]
@@ -140,9 +146,9 @@ class APICallPathFinder(BasePathFinder):
 
 class WebhookPathFinder(BasePathFinder):
     def _get_paths_iter(self, name: str) -> Iterator[Path]:
-        if "webhooks" not in self.spec:
-            raise PathNotFound("Webhooks not found")
         webhooks = self.spec / "webhooks"
+        if not webhooks.exists():
+            raise PathsNotFound(webhooks.as_uri())
         for webhook_name, path in list(webhooks.items()):
             if name == webhook_name:
                 path_result = TemplateResult(webhook_name, {})
